Event emitted when a thread is restored from the archive.
Summary
Types
@type t() :: %Codex.Events.ThreadUnarchived{thread_id: String.t()}
Event emitted when a thread is restored from the archive.
@type t() :: %Codex.Events.ThreadUnarchived{thread_id: String.t()}