Codex.FileSearch (Codex SDK v0.3.0)

Configuration for file search capabilities in threads and runs.

File search allows agents to search through uploaded files using vector stores.

Summary

Types

t()

@type t() :: %Codex.FileSearch{
  filters: map() | nil,
  include_search_results: boolean() | nil,
  ranking_options: map() | nil,
  vector_store_ids: [String.t()] | nil
}

Functions

merge(left, right)

@spec merge(t() | nil, t() | nil) :: t() | nil

new(config)

@spec new(map() | keyword() | t() | nil) :: {:ok, t() | nil} | {:error, term()}