Codex.Items.McpToolCall (Codex SDK v0.3.0)
View SourceMetadata describing a tool invocation routed through an MCP server.
Summary
Types
@type status() :: :in_progress | :completed | :failed
Metadata describing a tool invocation routed through an MCP server.
@type status() :: :in_progress | :completed | :failed