Types for agent-to-user input requests.
The RequestUserInput tool allows the agent to interactively ask the user questions during execution.
Types for agent-to-user input requests.
The RequestUserInput tool allows the agent to interactively ask the user questions during execution.