Codex.Protocol.TextElement (Codex SDK v0.16.1)

Copy Markdown View Source

Text element with byte range for rich text input.

Used to preserve UI element metadata in user input text.

Summary

Types

t()

A text element with byte range and optional placeholder

Types

t()

@type t() :: %Codex.Protocol.TextElement{
  byte_range: Codex.Protocol.ByteRange.t(),
  placeholder: (String.t() | nil) | nil
}

A text element with byte range and optional placeholder

Functions

from_map(data)

@spec from_map(map()) :: t()

to_map(te)

@spec to_map(t()) :: map()