Signals that the agent or run configuration was updated for this stream.
Summary
Types
@type t() :: %Codex.StreamEvent.AgentUpdated{ agent: Codex.Agent.t() | nil, run_config: Codex.RunConfig.t() | nil }
Signals that the agent or run configuration was updated for this stream.
@type t() :: %Codex.StreamEvent.AgentUpdated{ agent: Codex.Agent.t() | nil, run_config: Codex.RunConfig.t() | nil }