Codex.FileSearch (Codex SDK v0.3.0)
View SourceConfiguration for file search capabilities in threads and runs.
File search allows agents to search through uploaded files using vector stores.
Configuration for file search capabilities in threads and runs.
File search allows agents to search through uploaded files using vector stores.