Canonical local authoring paths for plugin manifests and marketplaces.
Summary
Functions
Resolves the canonical manifest path for a plugin root or manifest path.
Resolves the canonical marketplace path for a scope.
Returns the root directory that owns a canonical marketplace file.
Validates a marketplace source path before resolving it against the marketplace root.
Validates a manifest or marketplace relative path.
Resolves the canonical plugin root for a scope and plugin name.
Resolves a plugin root into a marketplace-relative ./... source path.
Resolves a marketplace entry source path to an absolute path under its root.
Resolves the root directory for a repo or personal plugin scope.
Types
Functions
Resolves the canonical manifest path for a plugin root or manifest path.
Resolves the canonical marketplace path for a scope.
Returns the root directory that owns a canonical marketplace file.
Validates a marketplace source path before resolving it against the marketplace root.
Validates a manifest or marketplace relative path.
Resolves the canonical plugin root for a scope and plugin name.
Resolves a plugin root into a marketplace-relative ./... source path.
@spec resolve_marketplace_source_path(String.t(), String.t()) :: {:ok, String.t()} | {:error, term()}
Resolves a marketplace entry source path to an absolute path under its root.
Resolves the root directory for a repo or personal plugin scope.