Text element with byte range for rich text input.
Used to preserve UI element metadata in user input text.
Summary
Types
@type t() :: %Codex.Protocol.TextElement{ byte_range: Codex.Protocol.ByteRange.t(), placeholder: (String.t() | nil) | nil }
A text element with byte range and optional placeholder